{% raw %}
{% load mote_tags %}
{% mask element.json.data.Logo as "logo" %}
  <a href="/" class="logo logo--{{logo.modifiers}}">
    <img src="{{logo.img.src}}" alt="{{logo.img.alt}}" width="140" height="auto">
  </a>
{% endraw %}
