{% load i18n %}

  <h1 class="heading heading--xx-large">{% trans "Topic of the Day" %}</h1>
  {% include "patterns/basics/article-teasers/topic-of-day_variations/topic-of-day-articles_default.html" %}
