# -*- coding: utf-8 -*-
# Generated by Django 1.9.10 on 2016-10-24 10:42
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('profiles', '0010_create_security_question_index_page'),
    ]

    operations = [
        migrations.AddField(
            model_name='userprofilessettings',
            name='country_code',
            field=models.CharField(blank=True, help_text='For example: +27 for South Africa, +44 for England', max_length=4, null=True, verbose_name="The country code that should be added to a user's number for this site"),
        ),
    ]
