.category {
    &__subcategory {
      margin: 0;
      color: #017AF5;
      text-transform: capitalize;
      padding: 5px 0;
    }
    &__link {
      color: #252627;
      vertical-align: middle;
      display: inline-block;
    }
    &__description {
      color: #5B5E5F;
      margin-top: 0;
      padding: 0 15px;
    }
    &__image-link {
      vertical-align: middle;
      padding: 0 0 0 15px;
      @media screen and (min-width: 320px) {
        border-radius: 100%;
        width: 20%;
      }
      img {
        vertical-align: middle;
        display: inline-block;
      }
    }
}
