COMMENTING_OPEN = 'O'
COMMENTING_CLOSED = 'C'
COMMENTING_DISABLED = 'D'
COMMENTING_TIMESTAMPED = 'T'

COMMENTING_STATE_CHOICES = (
    (COMMENTING_OPEN, 'Open'),
    (COMMENTING_CLOSED, 'Closed'),
    (COMMENTING_DISABLED, 'Disabled'),
    (COMMENTING_TIMESTAMPED, 'Timestamped'),
)
