 
{% extends "base.html" %}
{% load i18n %}

{% block body_class %}template-404{% endblock %}

{% block content %}
    <h2>{% trans "Access Denied" %}</h2>
    <p>{% trans "You do not have permission to access this site." %}</p>
    <p><a href="{% url 'wagtailadmin_logout' %}?next={% url 'wagtailadmin_login' %}">Retry</a></p>
{% endblock %}
 
