{% load i18n %}
  {% if languages|length > 1 %}
  <div class="languages">
    <ul class="language-list language-list--with-label">
      <li class="language-list__item language-list__item--with-label">
        <span class="language-list--with-label__title">{% trans "Language" %}</span>
      </li>
      {% for language in languages %}
      <li class="language-list__item language-list__item--with-label">
        <a href="{% url 'locale_set' language.locale %}?next={{request.path}}{% if request.GET.urlencode %}?{{ request.GET.urlencode }}{% endif %}" class="language-list__anchor language-list__anchor--with-label {% if LANGUAGE_CODE == language.locale %}is-active{% endif %}">
          {{language.locale|language_name_local}}
        </a>
      </li>
      {% endfor %}
    </ul>
  </div>
{% endif %}
