{% load wagtailcore_tags core_tags comments  molo_commenting_tags i18n %}
<div class="pagination">
  {% if replies.has_previous %}
    <a href="?p={{ replies.previous_page_number }}" class="pagination__nav-anchor-previous"></a>
  {% endif %}
  <span class="pagination__current-page">
    {% trans "Page" %} {{ replies.number }} {% trans "of" %} {{ replies.paginator.num_pages }}
  </span>
  {% if replies.has_next %}
    <a href="?p={{ replies.next_page_number }}" class="pagination__nav-anchor-next"></a>
  {% endif %}
</div>
