{% if hyperlink %}
  <a href="{{hyperlink}}" class="call-to-action__button call-to-action__button--{{type}}">
    <span class="call-to-action__button-text call-to-action__button-text--{{type}}">{{text}}</span>
  </a>
{% endif %}
