{% load core_tags wagtailcore_tags i18n  %}
<div class="pagination">
  {% if search_results.has_previous %}
    <a href="?p={{ search_results.previous_page_number }}&amp;q={{search_query}}" class="pagination__nav-anchor-previous"></a>
  {% endif %}
  <span class="pagination__nav-item-current">
    Page {{ search_results.number }} of {{ search_results.paginator.num_pages }}
  </span>
  {% if search_results.has_next %}
    <a href="?p={{ search_results.next_page_number }}&amp;q={{search_query}}" class="pagination__nav-anchor-next"></a>
  {% endif %}
</div>
