# -*- coding: utf-8 -*-
# Generated by Django 1.9.12 on 2017-03-08 14:17
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailcore', '0032_add_bulk_delete_page_permission'),
        ('profiles', '0013_add_location_gender_education_level_fields'),
    ]

    operations = [
        migrations.AddField(
            model_name='userprofile',
            name='site',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.Site'),
        ),
    ]
