{% include "patterns/basics/languages/language-list_dropdown.html" %}
<div class="header">
  <div class="header__menu">
      {% include "patterns/basics/images/logo.html" with class="left" %}
      {% include "patterns/basics/menu/menu-with_home-toggle.html" %}
  </div>
</div>
