.subsection-listing {
    &__theme-bg-title {
        padding: 5px 15px;
        @include heading-scale($heading-xx-large);
    }
    
    &__column {
        &-title {
          padding: 10px 15px;
        }
        &-link {
          &:hover {
            text-decoration: none;
          }
        }
    }
}
.subsection-list {
    &__theme-more-link {
      display: block;
      padding: 10px 15px;
      font-weight: bold;
      border-bottom: 1px solid #e6e6e6;
      &:after {
        padding: 0 0 0 10px;
        @media screen and (min-width: 320px) {
          content: ">";
        }
        @media screen and (min-width: 490px) {
          content: "❯";
        }
      }
      &:hover {
        text-decoration: none;
        opacity: 0.5;
      }
    }
}
