# -*- coding: utf-8 -*-
# Generated by Django 1.9.11 on 2016-11-14 13:52
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import wagtail.wagtailcore.blocks
import wagtail.wagtailcore.fields
import wagtail.wagtailimages.blocks


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailimages', '0012_copy_image_permissions_to_collections'),
        ('core', '0048_promotion_dates'),
    ]

    operations = [
        migrations.AddField(
            model_name='sitesettings',
            name='facebook_image',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image'),
        ),
        migrations.AddField(
            model_name='sitesettings',
            name='facebook_sharing',
            field=models.BooleanField(default=False, help_text=b'Enable this field to allow for sharing to Facebook.', verbose_name=b'Facebook'),
        ),
        migrations.AddField(
            model_name='sitesettings',
            name='social_media_links_on_footer_page',
            field=wagtail.wagtailcore.fields.StreamField([(b'social_media_site', wagtail.wagtailcore.blocks.StructBlock([(b'title', wagtail.wagtailcore.blocks.CharBlock(required=True)), (b'link', wagtail.wagtailcore.blocks.CharBlock(required=True)), (b'image', wagtail.wagtailimages.blocks.ImageChooserBlock())]))], blank=True, null=True),
        ),
        migrations.AddField(
            model_name='sitesettings',
            name='twitter_image',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image'),
        ),
        migrations.AddField(
            model_name='sitesettings',
            name='twitter_sharing',
            field=models.BooleanField(default=False, help_text=b'Enable this field to allow for sharing to Twitter.', verbose_name=b'Twitter'),
        ),
    ]
